summaryrefslogtreecommitdiff
path: root/TAO/orbsvcs/orbsvcs/FaultTolerance/FT_ClientRequest_Interceptor.h
diff options
context:
space:
mode:
Diffstat (limited to 'TAO/orbsvcs/orbsvcs/FaultTolerance/FT_ClientRequest_Interceptor.h')
-rw-r--r--TAO/orbsvcs/orbsvcs/FaultTolerance/FT_ClientRequest_Interceptor.h26
1 files changed, 11 insertions, 15 deletions
diff --git a/TAO/orbsvcs/orbsvcs/FaultTolerance/FT_ClientRequest_Interceptor.h b/TAO/orbsvcs/orbsvcs/FaultTolerance/FT_ClientRequest_Interceptor.h
index c4115555085..8f82b1f8089 100644
--- a/TAO/orbsvcs/orbsvcs/FaultTolerance/FT_ClientRequest_Interceptor.h
+++ b/TAO/orbsvcs/orbsvcs/FaultTolerance/FT_ClientRequest_Interceptor.h
@@ -1,5 +1,4 @@
// -*- C++ -*-
-
//=============================================================================
/**
* @file FT_ClientRequest_Interceptor.h
@@ -13,7 +12,7 @@
#define TAO_FT_CLIENT_REQUEST_INTERCEPTOR_H
#include /**/ "ace/pre.h"
-#include "orbsvcs/FaultTolerance/FT_ClientORB_export.h"
+#include "FT_ClientORB_export.h"
#if !defined (ACE_LACKS_PRAGMA_ONCE)
# pragma once
@@ -32,14 +31,11 @@
#pragma warning(disable:4250)
#endif /* _MSC_VER */
-ACE_BEGIN_VERSIONED_NAMESPACE_DECL
+
namespace ACE_Utils
{
class UUID;
}
-ACE_END_VERSIONED_NAMESPACE_DECL
-
-TAO_BEGIN_VERSIONED_NAMESPACE_DECL
namespace TAO
{
@@ -67,7 +63,7 @@ namespace TAO
*
* @@TODO
*/
- class FT_ClientRequest_Interceptor
+ class TAO_FT_ClientORB_Export FT_ClientRequest_Interceptor
: public virtual PortableInterceptor::ClientRequestInterceptor,
public virtual TAO_Local_RefCounted_Object
{
@@ -75,6 +71,8 @@ namespace TAO
FT_ClientRequest_Interceptor (void);
+ ~FT_ClientRequest_Interceptor (void);
+
/// Canonical name of the interceptor.
virtual char * name (ACE_ENV_SINGLE_ARG_DECL)
ACE_THROW_SPEC ((CORBA::SystemException));
@@ -106,10 +104,6 @@ namespace TAO
ACE_THROW_SPEC ((CORBA::SystemException,
PortableInterceptor::ForwardRequest));
- protected:
-
- ~FT_ClientRequest_Interceptor (void);
-
private:
void group_version_context (PortableInterceptor::ClientRequestInfo_ptr ri
@@ -124,6 +118,8 @@ namespace TAO
ACE_ENV_ARG_DECL)
ACE_THROW_SPEC ((CORBA::SystemException));
+ FT_TSS *tss_resources (void);
+
private:
/// Name of the interceptor
@@ -132,16 +128,16 @@ namespace TAO
/// UUID for this client
ACE_Utils::UUID *uuid_;
- /// @@ Need a resource factory for this too
+ /// TSS data
+ ACE_TSS_TYPE (FT_TSS) tss_;
+
+ /// @@ Need a resource factory for this too
ACE_Lock *lock_;
/// Retention id generated by the client
CORBA::Long retention_id_;
};
}
-
-TAO_END_VERSIONED_NAMESPACE_DECL
-
#if defined(_MSC_VER)
#pragma warning(pop)
#endif /* _MSC_VER */